@@ -27,24 +27,24 @@ from .literals import (
     StatusType,
 )
 from .type_defs import (
-    DescribeRecommendationExportJobsResponseTypeDef,
+    DescribeRecommendationExportJobsResponseResponseTypeDef,
     EBSFilterTypeDef,
-    ExportAutoScalingGroupRecommendationsResponseTypeDef,
-    ExportEBSVolumeRecommendationsResponseTypeDef,
-    ExportEC2InstanceRecommendationsResponseTypeDef,
-    ExportLambdaFunctionRecommendationsResponseTypeDef,
+    ExportAutoScalingGroupRecommendationsResponseResponseTypeDef,
+    ExportEBSVolumeRecommendationsResponseResponseTypeDef,
+    ExportEC2InstanceRecommendationsResponseResponseTypeDef,
+    ExportLambdaFunctionRecommendationsResponseResponseTypeDef,
     FilterTypeDef,
-    GetAutoScalingGroupRecommendationsResponseTypeDef,
-    GetEBSVolumeRecommendationsResponseTypeDef,
-    GetEC2InstanceRecommendationsResponseTypeDef,
-    GetEC2RecommendationProjectedMetricsResponseTypeDef,
-    GetEnrollmentStatusResponseTypeDef,
-    GetLambdaFunctionRecommendationsResponseTypeDef,
-    GetRecommendationSummariesResponseTypeDef,
+    GetAutoScalingGroupRecommendationsResponseResponseTypeDef,
+    GetEBSVolumeRecommendationsResponseResponseTypeDef,
+    GetEC2InstanceRecommendationsResponseResponseTypeDef,
+    GetEC2RecommendationProjectedMetricsResponseResponseTypeDef,
+    GetEnrollmentStatusResponseResponseTypeDef,
+    GetLambdaFunctionRecommendationsResponseResponseTypeDef,
+    GetRecommendationSummariesResponseResponseTypeDef,
     JobFilterTypeDef,
     LambdaFunctionRecommendationFilterTypeDef,
     S3DestinationConfigTypeDef,
-    UpdateEnrollmentStatusResponseTypeDef,
+    UpdateEnrollmentStatusResponseResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -79,7 +79,7 @@ class Exceptions:
 
 class ComputeOptimizerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html)
     """
 
@@ -90,7 +90,7 @@ class ComputeOptimizerClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#can_paginate)
         """
 
@@ -101,11 +101,11 @@ class ComputeOptimizerClient:
         filters: List["JobFilterTypeDef"] = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> DescribeRecommendationExportJobsResponseTypeDef:
+    ) -> DescribeRecommendationExportJobsResponseResponseTypeDef:
         """
         Describes recommendation export jobs created in the last seven days.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#describe_recommendation_export_jobs)
         """
 
@@ -118,11 +118,11 @@ class ComputeOptimizerClient:
         fieldsToExport: List[ExportableAutoScalingGroupFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
-    ) -> ExportAutoScalingGroupRecommendationsResponseTypeDef:
+    ) -> ExportAutoScalingGroupRecommendationsResponseResponseTypeDef:
         """
         Exports optimization recommendations for Auto Scaling groups.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_auto_scaling_group_recommendations)
         """
 
@@ -135,11 +135,11 @@ class ComputeOptimizerClient:
         fieldsToExport: List[ExportableVolumeFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
-    ) -> ExportEBSVolumeRecommendationsResponseTypeDef:
+    ) -> ExportEBSVolumeRecommendationsResponseResponseTypeDef:
         """
         Exports optimization recommendations for Amazon EBS volumes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ebs_volume_recommendations)
         """
 
@@ -152,11 +152,11 @@ class ComputeOptimizerClient:
         fieldsToExport: List[ExportableInstanceFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
-    ) -> ExportEC2InstanceRecommendationsResponseTypeDef:
+    ) -> ExportEC2InstanceRecommendationsResponseResponseTypeDef:
         """
         Exports optimization recommendations for Amazon EC2 instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ec2_instance_recommendations)
         """
 
@@ -169,11 +169,11 @@ class ComputeOptimizerClient:
         fieldsToExport: List[ExportableLambdaFunctionFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
-    ) -> ExportLambdaFunctionRecommendationsResponseTypeDef:
+    ) -> ExportLambdaFunctionRecommendationsResponseResponseTypeDef:
         """
         Exports optimization recommendations for AWS Lambda functions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_lambda_function_recommendations)
         """
 
@@ -187,7 +187,7 @@ class ComputeOptimizerClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#generate_presigned_url)
         """
 
@@ -199,11 +199,11 @@ class ComputeOptimizerClient:
         nextToken: str = None,
         maxResults: int = None,
         filters: List["FilterTypeDef"] = None
-    ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
+    ) -> GetAutoScalingGroupRecommendationsResponseResponseTypeDef:
         """
         Returns Auto Scaling group recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_auto_scaling_group_recommendations)
         """
 
@@ -215,11 +215,11 @@ class ComputeOptimizerClient:
         maxResults: int = None,
         filters: List["EBSFilterTypeDef"] = None,
         accountIds: List[str] = None
-    ) -> GetEBSVolumeRecommendationsResponseTypeDef:
+    ) -> GetEBSVolumeRecommendationsResponseResponseTypeDef:
         """
         Returns Amazon Elastic Block Store (Amazon EBS) volume recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ebs_volume_recommendations)
         """
 
@@ -231,11 +231,11 @@ class ComputeOptimizerClient:
         maxResults: int = None,
         filters: List["FilterTypeDef"] = None,
         accountIds: List[str] = None
-    ) -> GetEC2InstanceRecommendationsResponseTypeDef:
+    ) -> GetEC2InstanceRecommendationsResponseResponseTypeDef:
         """
         Returns Amazon EC2 instance recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_instance_recommendations)
         """
 
@@ -247,21 +247,21 @@ class ComputeOptimizerClient:
         period: int,
         startTime: Union[datetime, str],
         endTime: Union[datetime, str]
-    ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
+    ) -> GetEC2RecommendationProjectedMetricsResponseResponseTypeDef:
         """
         Returns the projected utilization metrics of Amazon EC2 instance
         recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_recommendation_projected_metrics)
         """
 
-    def get_enrollment_status(self) -> GetEnrollmentStatusResponseTypeDef:
+    def get_enrollment_status(self) -> GetEnrollmentStatusResponseResponseTypeDef:
         """
         Returns the enrollment (opt in) status of an account to the AWS Compute
         Optimizer service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_enrollment_status)
         """
 
@@ -273,31 +273,31 @@ class ComputeOptimizerClient:
         filters: List["LambdaFunctionRecommendationFilterTypeDef"] = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> GetLambdaFunctionRecommendationsResponseTypeDef:
+    ) -> GetLambdaFunctionRecommendationsResponseResponseTypeDef:
         """
         Returns AWS Lambda function recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_lambda_function_recommendations)
         """
 
     def get_recommendation_summaries(
         self, *, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
-    ) -> GetRecommendationSummariesResponseTypeDef:
+    ) -> GetRecommendationSummariesResponseResponseTypeDef:
         """
         Returns the optimization findings for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_recommendation_summaries)
         """
 
     def update_enrollment_status(
         self, *, status: StatusType, includeMemberAccounts: bool = None
-    ) -> UpdateEnrollmentStatusResponseTypeDef:
+    ) -> UpdateEnrollmentStatusResponseResponseTypeDef:
         """
         Updates the enrollment (opt in and opt out) status of an account to the AWS
         Compute Optimizer service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#update_enrollment_status)
         """
