@@ -13,11 +13,15 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import List
+from typing import Any, Dict, List, Union
 
 from .literals import (
     EBSFindingType,
     EBSMetricNameType,
+    ExportableAutoScalingGroupFieldType,
+    ExportableInstanceFieldType,
+    ExportableLambdaFunctionFieldType,
+    ExportableVolumeFieldType,
     FilterNameType,
     FindingReasonCodeType,
     FindingType,
@@ -52,23 +56,34 @@ __all__ = (
     "AutoScalingGroupConfigurationTypeDef",
     "AutoScalingGroupRecommendationOptionTypeDef",
     "AutoScalingGroupRecommendationTypeDef",
-    "DescribeRecommendationExportJobsResponseTypeDef",
+    "DescribeRecommendationExportJobsRequestTypeDef",
+    "DescribeRecommendationExportJobsResponseResponseTypeDef",
     "EBSFilterTypeDef",
     "EBSUtilizationMetricTypeDef",
-    "ExportAutoScalingGroupRecommendationsResponseTypeDef",
+    "ExportAutoScalingGroupRecommendationsRequestTypeDef",
+    "ExportAutoScalingGroupRecommendationsResponseResponseTypeDef",
     "ExportDestinationTypeDef",
-    "ExportEBSVolumeRecommendationsResponseTypeDef",
-    "ExportEC2InstanceRecommendationsResponseTypeDef",
-    "ExportLambdaFunctionRecommendationsResponseTypeDef",
+    "ExportEBSVolumeRecommendationsRequestTypeDef",
+    "ExportEBSVolumeRecommendationsResponseResponseTypeDef",
+    "ExportEC2InstanceRecommendationsRequestTypeDef",
+    "ExportEC2InstanceRecommendationsResponseResponseTypeDef",
+    "ExportLambdaFunctionRecommendationsRequestTypeDef",
+    "ExportLambdaFunctionRecommendationsResponseResponseTypeDef",
     "FilterTypeDef",
-    "GetAutoScalingGroupRecommendationsResponseTypeDef",
-    "GetEBSVolumeRecommendationsResponseTypeDef",
-    "GetEC2InstanceRecommendationsResponseTypeDef",
-    "GetEC2RecommendationProjectedMetricsResponseTypeDef",
-    "GetEnrollmentStatusResponseTypeDef",
-    "GetLambdaFunctionRecommendationsResponseTypeDef",
+    "GetAutoScalingGroupRecommendationsRequestTypeDef",
+    "GetAutoScalingGroupRecommendationsResponseResponseTypeDef",
+    "GetEBSVolumeRecommendationsRequestTypeDef",
+    "GetEBSVolumeRecommendationsResponseResponseTypeDef",
+    "GetEC2InstanceRecommendationsRequestTypeDef",
+    "GetEC2InstanceRecommendationsResponseResponseTypeDef",
+    "GetEC2RecommendationProjectedMetricsRequestTypeDef",
+    "GetEC2RecommendationProjectedMetricsResponseResponseTypeDef",
+    "GetEnrollmentStatusResponseResponseTypeDef",
+    "GetLambdaFunctionRecommendationsRequestTypeDef",
+    "GetLambdaFunctionRecommendationsResponseResponseTypeDef",
     "GetRecommendationErrorTypeDef",
-    "GetRecommendationSummariesResponseTypeDef",
+    "GetRecommendationSummariesRequestTypeDef",
+    "GetRecommendationSummariesResponseResponseTypeDef",
     "InstanceRecommendationOptionTypeDef",
     "InstanceRecommendationTypeDef",
     "JobFilterTypeDef",
@@ -83,10 +98,12 @@ __all__ = (
     "RecommendationSourceTypeDef",
     "RecommendationSummaryTypeDef",
     "RecommendedOptionProjectedMetricTypeDef",
+    "ResponseMetadataTypeDef",
     "S3DestinationConfigTypeDef",
     "S3DestinationTypeDef",
     "SummaryTypeDef",
-    "UpdateEnrollmentStatusResponseTypeDef",
+    "UpdateEnrollmentStatusRequestTypeDef",
+    "UpdateEnrollmentStatusResponseResponseTypeDef",
     "UtilizationMetricTypeDef",
     "VolumeConfigurationTypeDef",
     "VolumeRecommendationOptionTypeDef",
@@ -131,13 +148,24 @@ AutoScalingGroupRecommendationTypeDef = TypedDict(
     total=False,
 )
 
-DescribeRecommendationExportJobsResponseTypeDef = TypedDict(
-    "DescribeRecommendationExportJobsResponseTypeDef",
+DescribeRecommendationExportJobsRequestTypeDef = TypedDict(
+    "DescribeRecommendationExportJobsRequestTypeDef",
+    {
+        "jobIds": List[str],
+        "filters": List["JobFilterTypeDef"],
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+DescribeRecommendationExportJobsResponseResponseTypeDef = TypedDict(
+    "DescribeRecommendationExportJobsResponseResponseTypeDef",
     {
         "recommendationExportJobs": List["RecommendationExportJobTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 EBSFilterTypeDef = TypedDict(
@@ -159,13 +187,39 @@ EBSUtilizationMetricTypeDef = TypedDict(
     total=False,
 )
 
-ExportAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
-    "ExportAutoScalingGroupRecommendationsResponseTypeDef",
+_RequiredExportAutoScalingGroupRecommendationsRequestTypeDef = TypedDict(
+    "_RequiredExportAutoScalingGroupRecommendationsRequestTypeDef",
+    {
+        "s3DestinationConfig": "S3DestinationConfigTypeDef",
+    },
+)
+_OptionalExportAutoScalingGroupRecommendationsRequestTypeDef = TypedDict(
+    "_OptionalExportAutoScalingGroupRecommendationsRequestTypeDef",
+    {
+        "accountIds": List[str],
+        "filters": List["FilterTypeDef"],
+        "fieldsToExport": List[ExportableAutoScalingGroupFieldType],
+        "fileFormat": Literal["Csv"],
+        "includeMemberAccounts": bool,
+    },
+    total=False,
+)
+
+
+class ExportAutoScalingGroupRecommendationsRequestTypeDef(
+    _RequiredExportAutoScalingGroupRecommendationsRequestTypeDef,
+    _OptionalExportAutoScalingGroupRecommendationsRequestTypeDef,
+):
+    pass
+
+
+ExportAutoScalingGroupRecommendationsResponseResponseTypeDef = TypedDict(
+    "ExportAutoScalingGroupRecommendationsResponseResponseTypeDef",
     {
         "jobId": str,
         "s3Destination": "S3DestinationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ExportDestinationTypeDef = TypedDict(
@@ -176,33 +230,111 @@ ExportDestinationTypeDef = TypedDict(
     total=False,
 )
 
-ExportEBSVolumeRecommendationsResponseTypeDef = TypedDict(
-    "ExportEBSVolumeRecommendationsResponseTypeDef",
+_RequiredExportEBSVolumeRecommendationsRequestTypeDef = TypedDict(
+    "_RequiredExportEBSVolumeRecommendationsRequestTypeDef",
     {
-        "jobId": str,
-        "s3Destination": "S3DestinationTypeDef",
+        "s3DestinationConfig": "S3DestinationConfigTypeDef",
+    },
+)
+_OptionalExportEBSVolumeRecommendationsRequestTypeDef = TypedDict(
+    "_OptionalExportEBSVolumeRecommendationsRequestTypeDef",
+    {
+        "accountIds": List[str],
+        "filters": List["EBSFilterTypeDef"],
+        "fieldsToExport": List[ExportableVolumeFieldType],
+        "fileFormat": Literal["Csv"],
+        "includeMemberAccounts": bool,
     },
     total=False,
 )
 
-ExportEC2InstanceRecommendationsResponseTypeDef = TypedDict(
-    "ExportEC2InstanceRecommendationsResponseTypeDef",
+
+class ExportEBSVolumeRecommendationsRequestTypeDef(
+    _RequiredExportEBSVolumeRecommendationsRequestTypeDef,
+    _OptionalExportEBSVolumeRecommendationsRequestTypeDef,
+):
+    pass
+
+
+ExportEBSVolumeRecommendationsResponseResponseTypeDef = TypedDict(
+    "ExportEBSVolumeRecommendationsResponseResponseTypeDef",
     {
         "jobId": str,
         "s3Destination": "S3DestinationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredExportEC2InstanceRecommendationsRequestTypeDef = TypedDict(
+    "_RequiredExportEC2InstanceRecommendationsRequestTypeDef",
+    {
+        "s3DestinationConfig": "S3DestinationConfigTypeDef",
+    },
+)
+_OptionalExportEC2InstanceRecommendationsRequestTypeDef = TypedDict(
+    "_OptionalExportEC2InstanceRecommendationsRequestTypeDef",
+    {
+        "accountIds": List[str],
+        "filters": List["FilterTypeDef"],
+        "fieldsToExport": List[ExportableInstanceFieldType],
+        "fileFormat": Literal["Csv"],
+        "includeMemberAccounts": bool,
     },
     total=False,
 )
 
-ExportLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
-    "ExportLambdaFunctionRecommendationsResponseTypeDef",
+
+class ExportEC2InstanceRecommendationsRequestTypeDef(
+    _RequiredExportEC2InstanceRecommendationsRequestTypeDef,
+    _OptionalExportEC2InstanceRecommendationsRequestTypeDef,
+):
+    pass
+
+
+ExportEC2InstanceRecommendationsResponseResponseTypeDef = TypedDict(
+    "ExportEC2InstanceRecommendationsResponseResponseTypeDef",
     {
         "jobId": str,
         "s3Destination": "S3DestinationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredExportLambdaFunctionRecommendationsRequestTypeDef = TypedDict(
+    "_RequiredExportLambdaFunctionRecommendationsRequestTypeDef",
+    {
+        "s3DestinationConfig": "S3DestinationConfigTypeDef",
+    },
+)
+_OptionalExportLambdaFunctionRecommendationsRequestTypeDef = TypedDict(
+    "_OptionalExportLambdaFunctionRecommendationsRequestTypeDef",
+    {
+        "accountIds": List[str],
+        "filters": List["LambdaFunctionRecommendationFilterTypeDef"],
+        "fieldsToExport": List[ExportableLambdaFunctionFieldType],
+        "fileFormat": Literal["Csv"],
+        "includeMemberAccounts": bool,
     },
     total=False,
 )
 
+
+class ExportLambdaFunctionRecommendationsRequestTypeDef(
+    _RequiredExportLambdaFunctionRecommendationsRequestTypeDef,
+    _OptionalExportLambdaFunctionRecommendationsRequestTypeDef,
+):
+    pass
+
+
+ExportLambdaFunctionRecommendationsResponseResponseTypeDef = TypedDict(
+    "ExportLambdaFunctionRecommendationsResponseResponseTypeDef",
+    {
+        "jobId": str,
+        "s3Destination": "S3DestinationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
@@ -212,61 +344,120 @@ FilterTypeDef = TypedDict(
     total=False,
 )
 
-GetAutoScalingGroupRecommendationsResponseTypeDef = TypedDict(
-    "GetAutoScalingGroupRecommendationsResponseTypeDef",
+GetAutoScalingGroupRecommendationsRequestTypeDef = TypedDict(
+    "GetAutoScalingGroupRecommendationsRequestTypeDef",
+    {
+        "accountIds": List[str],
+        "autoScalingGroupArns": List[str],
+        "nextToken": str,
+        "maxResults": int,
+        "filters": List["FilterTypeDef"],
+    },
+    total=False,
+)
+
+GetAutoScalingGroupRecommendationsResponseResponseTypeDef = TypedDict(
+    "GetAutoScalingGroupRecommendationsResponseResponseTypeDef",
     {
         "nextToken": str,
         "autoScalingGroupRecommendations": List["AutoScalingGroupRecommendationTypeDef"],
         "errors": List["GetRecommendationErrorTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetEBSVolumeRecommendationsRequestTypeDef = TypedDict(
+    "GetEBSVolumeRecommendationsRequestTypeDef",
+    {
+        "volumeArns": List[str],
+        "nextToken": str,
+        "maxResults": int,
+        "filters": List["EBSFilterTypeDef"],
+        "accountIds": List[str],
     },
     total=False,
 )
 
-GetEBSVolumeRecommendationsResponseTypeDef = TypedDict(
-    "GetEBSVolumeRecommendationsResponseTypeDef",
+GetEBSVolumeRecommendationsResponseResponseTypeDef = TypedDict(
+    "GetEBSVolumeRecommendationsResponseResponseTypeDef",
     {
         "nextToken": str,
         "volumeRecommendations": List["VolumeRecommendationTypeDef"],
         "errors": List["GetRecommendationErrorTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetEC2InstanceRecommendationsRequestTypeDef = TypedDict(
+    "GetEC2InstanceRecommendationsRequestTypeDef",
+    {
+        "instanceArns": List[str],
+        "nextToken": str,
+        "maxResults": int,
+        "filters": List["FilterTypeDef"],
+        "accountIds": List[str],
     },
     total=False,
 )
 
-GetEC2InstanceRecommendationsResponseTypeDef = TypedDict(
-    "GetEC2InstanceRecommendationsResponseTypeDef",
+GetEC2InstanceRecommendationsResponseResponseTypeDef = TypedDict(
+    "GetEC2InstanceRecommendationsResponseResponseTypeDef",
     {
         "nextToken": str,
         "instanceRecommendations": List["InstanceRecommendationTypeDef"],
         "errors": List["GetRecommendationErrorTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetEC2RecommendationProjectedMetricsResponseTypeDef = TypedDict(
-    "GetEC2RecommendationProjectedMetricsResponseTypeDef",
+GetEC2RecommendationProjectedMetricsRequestTypeDef = TypedDict(
+    "GetEC2RecommendationProjectedMetricsRequestTypeDef",
+    {
+        "instanceArn": str,
+        "stat": MetricStatisticType,
+        "period": int,
+        "startTime": Union[datetime, str],
+        "endTime": Union[datetime, str],
+    },
+)
+
+GetEC2RecommendationProjectedMetricsResponseResponseTypeDef = TypedDict(
+    "GetEC2RecommendationProjectedMetricsResponseResponseTypeDef",
     {
         "recommendedOptionProjectedMetrics": List["RecommendedOptionProjectedMetricTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetEnrollmentStatusResponseTypeDef = TypedDict(
-    "GetEnrollmentStatusResponseTypeDef",
+GetEnrollmentStatusResponseResponseTypeDef = TypedDict(
+    "GetEnrollmentStatusResponseResponseTypeDef",
     {
         "status": StatusType,
         "statusReason": str,
         "memberAccountsEnrolled": bool,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetLambdaFunctionRecommendationsRequestTypeDef = TypedDict(
+    "GetLambdaFunctionRecommendationsRequestTypeDef",
+    {
+        "functionArns": List[str],
+        "accountIds": List[str],
+        "filters": List["LambdaFunctionRecommendationFilterTypeDef"],
+        "nextToken": str,
+        "maxResults": int,
     },
     total=False,
 )
 
-GetLambdaFunctionRecommendationsResponseTypeDef = TypedDict(
-    "GetLambdaFunctionRecommendationsResponseTypeDef",
+GetLambdaFunctionRecommendationsResponseResponseTypeDef = TypedDict(
+    "GetLambdaFunctionRecommendationsResponseResponseTypeDef",
     {
         "nextToken": str,
         "lambdaFunctionRecommendations": List["LambdaFunctionRecommendationTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 GetRecommendationErrorTypeDef = TypedDict(
@@ -279,13 +470,23 @@ GetRecommendationErrorTypeDef = TypedDict(
     total=False,
 )
 
-GetRecommendationSummariesResponseTypeDef = TypedDict(
-    "GetRecommendationSummariesResponseTypeDef",
+GetRecommendationSummariesRequestTypeDef = TypedDict(
+    "GetRecommendationSummariesRequestTypeDef",
+    {
+        "accountIds": List[str],
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
+GetRecommendationSummariesResponseResponseTypeDef = TypedDict(
+    "GetRecommendationSummariesResponseResponseTypeDef",
     {
         "nextToken": str,
         "recommendationSummaries": List["RecommendationSummaryTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 InstanceRecommendationOptionTypeDef = TypedDict(
@@ -446,6 +647,17 @@ RecommendedOptionProjectedMetricTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 S3DestinationConfigTypeDef = TypedDict(
     "S3DestinationConfigTypeDef",
     {
@@ -475,13 +687,34 @@ SummaryTypeDef = TypedDict(
     total=False,
 )
 
-UpdateEnrollmentStatusResponseTypeDef = TypedDict(
-    "UpdateEnrollmentStatusResponseTypeDef",
+_RequiredUpdateEnrollmentStatusRequestTypeDef = TypedDict(
+    "_RequiredUpdateEnrollmentStatusRequestTypeDef",
+    {
+        "status": StatusType,
+    },
+)
+_OptionalUpdateEnrollmentStatusRequestTypeDef = TypedDict(
+    "_OptionalUpdateEnrollmentStatusRequestTypeDef",
+    {
+        "includeMemberAccounts": bool,
+    },
+    total=False,
+)
+
+
+class UpdateEnrollmentStatusRequestTypeDef(
+    _RequiredUpdateEnrollmentStatusRequestTypeDef, _OptionalUpdateEnrollmentStatusRequestTypeDef
+):
+    pass
+
+
+UpdateEnrollmentStatusResponseResponseTypeDef = TypedDict(
+    "UpdateEnrollmentStatusResponseResponseTypeDef",
     {
         "status": StatusType,
         "statusReason": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 UtilizationMetricTypeDef = TypedDict(
